Cosmetics.
[selector.git] / mkdeb.sh
index 51d023a..291c677 100755 (executable)
--- a/mkdeb.sh
+++ b/mkdeb.sh
@@ -1,11 +1,11 @@
 #!/bin/bash
 
 #
#  selector is a simple shell command for selection of strings with a
#  dynamic pattern-matching.
 #
 #  Copyright (c) 2009 Francois Fleuret
-#  Written by Francois Fleuret <francois.fleuret@idiap.ch>
+#  Written by Francois Fleuret <francois@fleuret.org>
 #
 #  This file is part of selector.
 #
 # This script creates the Debian package. The way it does it is
 # probably not very conventional. I am open to suggestions.
 
-VERSION=1.0-R`git log | grep ^commit | wc -l | sed -e "s/[^0-9]//g"`
+VERSION=1.0-R$(cat REVISION_NUMBER)
 PACKAGE=/tmp/selector_${VERSION}_i386.deb
+
 BIN_PATH="usr/bin"
 MAN_PATH="usr/share/man/man1"
-make -k
+
+make -j -k || exit 1
 
 TMP=`mktemp -d /tmp/deb.XXXXXX`
 
@@ -45,14 +47,14 @@ Version: ${VERSION}
 Maintainer: Francois Fleuret <francois@fleuret.org>
 Architecture: i386
 Depends: ${LIB_DEPENDS}
-Description: A command line for dynamic string-matching
- This is a command line for dynamic string selection. As you type a
- list of substrings separated by ';', or a regexp, the display is
- updated in real time to show only the matching lines. The main usage
- of selector is as an efficient search in the shell command
+Description: A command line utility for dynamic string-matching
+ This is a command line utility for dynamic string selection. As you
+ type a list of substrings separated by ';', or a regexp, the display
+ is updated in real time to show only the matching lines. The main
usage of selector is as an efficient search in the shell command
  history. With the correct option, it will inject the selected line
- into the virtual tty input buffer, hence allowing the user to edit
the line and execute it as a standard command.
+ into the tty input buffer, hence allowing the user to edit the line
+ and execute it as a standard command.
 EOF
 
 cp ./selector ${TMP}/${BIN_PATH}
@@ -1,11 +1,11 @@
 
 #
-#  selector is a simple shell command for selection of strings with a
-#  dynamic pattern-matching.
+#  selector is a simple command line utility for selection of strings
+#  with a dynamic pattern-matching.
 #
 #  Copyright (c) 2009 Francois Fleuret